==> evolution-1.3.3.zip: evolution-1.3.3/assets/modules/store/lang/english.php <==
<?php
/*List pack */
$_Lang['version'] = "Version";
$_Lang['suthor'] = "author";
$_Lang['date'] = "Issued";
$_Lang['downloads'] = "Uploaded";
$_Lang['install'] = "Install";
$_Lang['reinstall'] = "Reset";
$_Lang['update'] = "Update";
$_Lang['installed'] = "established";
$_Lang['installed2'] = "Installed";
$_Lang['exit'] = "Exit";
$_Lang['alert_overwrite'] = "Installing this add-on will overwrite the existing ones. Continue?";

/*Main*/
$_Lang['store_name'] = "Package Management";
$_Lang['version_evailble'] = "A new version";
$_Lang['category'] = "Categories";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Login to your repository";
$_Lang['password'] = "Password";
$_Lang['enter'] = "&nbsp;&nbsp; &nbsp; &nbsp; &nbsp; Login &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;";
$_Lang['email'] = "Email";
$_Lang['register'] = "Sign up now";
$_Lang['own_repository'] = "My Repository";
$_Lang['login_errors'] = "Incorrect Email or Password";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Created";
$_Lang['s1_2_name'] = "Title";
$_Lang['s1_3_position'] = "Position";
$_Lang['s1_4_published'] = "Update";
$_Lang['s2_1_up'] = "Descending";
$_Lang['s2_2_down'] = "Ascending";
$_Lang['search'] = "Search in category: ";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/faq/whatfor.html" target="_blank">Why do you need repository</a></li>
<li><a href="http://extras.evolution-cms.com/faq/howtoadd.html" target="_blank">How to add a package to the repository</a></li>
<li><a href="http://extras.evolution-cms.com/faq/howtocollect.html" target="_blank">How to create a package for installation</a></li>';

?>

==> evolution-1.4.3.zip: evolution-1.4.3/assets/modules/store/lang/english.php <==
<?php
/*List pack */
$_Lang['version'] = "Version";
$_Lang['suthor'] = "author";
$_Lang['date'] = "Issued";
$_Lang['downloads'] = "Uploaded";
$_Lang['install'] = "Install";
$_Lang['reinstall'] = "Reset";
$_Lang['update'] = "Update";
$_Lang['installed'] = "established";
$_Lang['installed2'] = "Installed";
$_Lang['exit'] = "Exit";
$_Lang['alert_overwrite'] = "Installing this add-on will overwrite the existing ones. Continue?";

/*Main*/
$_Lang['store_name'] = "Package Management";
$_Lang['version_evailble'] = "A new version";
$_Lang['category'] = "Categories";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Login to your repository";
$_Lang['password'] = "Password";
$_Lang['enter'] = "&nbsp;&nbsp; &nbsp; &nbsp; &nbsp; Login &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;";
$_Lang['email'] = "Email";
$_Lang['register'] = "Sign up now";
$_Lang['own_repository'] = "My Repository";
$_Lang['login_errors'] = "Incorrect Email or Password";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Created";
$_Lang['s1_2_name'] = "Title";
$_Lang['s1_3_position'] = "Position";
$_Lang['s1_4_published'] = "Update";
$_Lang['s2_1_up'] = "Descending";
$_Lang['s2_2_down'] = "Ascending";
$_Lang['search'] = "Search in category: ";

/* Installation by file-upload */
$_Lang['install_file'] = "Install by file";
$_Lang['choose_file_msg'] = "Choose a file to upload and install";
$_Lang['install_file_btn'] = "Install";
$_Lang['install_file_success'] = "Installation successful";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/faq/whatfor.html" target="_blank">Why do you need repository</a></li>
<li><a href="http://extras.evolution-cms.com/faq/howtoadd.html" target="_blank">How to add a package to the repository</a></li>
<li><a href="http://extras.evolution-cms.com/faq/howtocollect.html" target="_blank">How to create a package for installation</a></li>';

?>
